package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`%0`!````!"(`$`````!``````````+@!`0``
M`````@```$``.``(`$``&@`9``8````%````0`````````!````0`````$``
M`!``````P`$```````#``0````````@``````````P````0``````@``````
M```"`!````````(`$``````1`````````!$``````````0`````````!````
M!0``````````````````$``````````0`````+3!````````M,$`````````
M``$```````$````&````V/T```````#8_0$0`````-C]`1``````N`(`````
M```H%0```````````0```````@````8```#P_0```````/#]`1``````\/T!
M$``````0`@```````!`"````````"``````````$````!````!0"````````
M%`(`$``````4`@`0`````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#8_0```````-C]`1``````V/T!$``````H`@``````
M`"@"`````````0`````````O;&EB-C0O;&0V-"YS;RXR``````0````0````
M`0```$=.50```````@````8````@````!````!0````#````1TY5`'6U;.V8
M@AN?#D^=Q,:<TE1I"G^3$0```$\````$````"````"`0$``%0`2$*@(``("&
M`*""*0``"2`$"8B@&$6Z!`((`````$\```!3````6````%D```!?````8```
M`&$```!C````9`````````!F````9P```&@```!I``````````````!NQ=\?
MZM/O#L[>1RUK?YI\+L6;MB#_Y`Y\08[%N(WQ#M5DU'S9<5@<XD?&`:Q+X\"Z
MXY)\PN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZ
MEPM_J9R;X:<""J/@^TD```````````````````````````````#S`@``$@``
M``````````````````````!O`P``$@````````````````````````##`@``
M$@````````````````````````#*`@``$@````````````````````````!A
M`P``$@````````````````````````!P`@``$@``````````````````````
M```1````(``````````````````````````;`P``$@``````````````````
M```````S`P``$@`````````````````````````L`P``$@``````````````
M```````````3`P``$@````````````````````````#3````$@``````````
M```````````````E`P``$0````````````````````````"]`0``$@``````
M``````````````````!>`@``$@````````````````````````!]`@``$@``
M``````````````````````"O````$@`````````````````````````X`0``
M$@````````````````````````!#`P``$@````````````````````````"\
M`@``$@````````````````````````#D`0``$@``````````````````````
M```M`0``$0````````````````````````#Z`@``$@``````````````````
M``````"A`0``$@`````````````````````````"`0``$0``````````````
M``````````!A`0``$@````````````````````````!U`@``$@``````````
M``````````````"%`P``$@````````````````````````#1`@``$@``````
M``````````````````#A````$@````````````````````````#K`0``$@``
M``````````````````````!'`@``$@````````````````````````"(`0``
M$@````````````````````````#8`0``$@`````````````````````````5
M`@``$@````````````````````````"M`@``$@``````````````````````
M``"&`@``$@````````````````````````"/`@``$@``````````````````
M```````I`@``$@````````````````````````!O`0``$@``````````````
M```````````M````(`````````````````````````"8`P``(0``````````
M``````````````!W`P``$@````````````````````````#V`0``$0``````
M``````````````````!X````$@`````````````````````````\`P``$@``
M``````````````````````#E`@``$@`````````````````````````/`0``
M$@````````````````````````!^`P``$@````````````````````````#L
M`P``$@````````````````````````#?`@``$@``````````````````````
M``"^````$@````````````````````````"6`0``$@``````````````````
M```````(`P``$@````````````````````````!.`0``$@``````````````
M```````````]`0``$@````````````````````````!J````$@``````````
M``````````````!7`P``$@````````````````````````!"`0``$@``````
M``````````````````#-`0``$@`````````````````````````<`0``$@``
M``````````````````````!0`P``$@````````````````````````"O`0``
M$@````````````````````````">````$@````````````````````````!/
M`@``$@````````````````````````"U`@``$@``````````````````````
M``"7`P``$0````````````````````````"9`P``$0``````````````````
M```````\````(``````````````````````````O`@``$@``````````````
M``````````#S````$@````````````````````````!_`0``$@``````````
M``````````````#8`@``$@````````````````````````"'````$@``````
M``````````````````!0````(``````````````````````````V`@``$@``
M``````````````````````"@`@``$@````````````````````````"G`@``
M$@````````````````````````#U`P``$F`,`,!Z`!``````^`$```````##
M`P``$F`-`.!_`!`````````````````:!```$F`,`$!D`!``````Z`\`````
M``"2`P``$F`,`.`>`!``````)`,```````#)`P``$F`,`.!+`!``````&```
M``````"(!```$F`,``!,`!``````1`,```````"U!```$F`,`,!\`!``````
M>`````````""!```$F`+`)`:`!````````````````#1!```$F`,`#!T`!``
M````C`8```````"H`P``$``6`)```A`````````````````!!```$@`,`%!/
M`!``````6``````````T!```$0`.`#"``!``````!`````````"T`P``$``7
M```3`A````````````````"`!```$F`,`'!*`!``````9`````````"5!```
M$F`,`.!A`!``````7`(```````"G!```$F`,`&!@`!``````&`$````````G
M!```$``4`````A`````````````````.!```$F`,`+!/`!``````X`$`````
M``"A`P``$``5`)```A````````````````!I!```$0`4`!@``A``````"```
M``````"Y`P``$@`,`(!^`!``````$`````````!9!```$F`,`*!]`!``````
MU``````````M!```$F`,``0B`!``````1``````````I!```(``4`````A``
M``````````````#:`P``$F`,`(!A`!``````5`````````!#!```$F`,`.!*
M`!``````_`````````!S!```$F`,`)!1`!``````S`X`````````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U
M<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?
M<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?
M0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P``
M``(``@`"``(``@`"`````@`"``(``@````(````"``(```````(``@`"````
M`@`````````"``(``@```````P```````P`"``(``@`#```````"``(`````
M``(``@````(``@`"```````"`````@````(``````````@```````P`"``(`
M`@````,```````(```````,``@`"``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`!``4"```0````
M(````)>1E@8```,`YP0````````!``$`5`(``!``````````EY&6!@```@#G
M!````````"@``A``````)@```"D``````````````%```A``````)@```$0`
M`````````````%@``A``````)@```!8``````````````&```A``````)@``
M``X``````````````&@``A``````)@````T``````````````'```A``````
M)@```$```````````````'@``A``````)@```#<``````````````(```A``
M````)@```!D``````````````(@``A``````)@```"P``````````````*``
M`A``````%0````$``````````````*@``A``````%0````(`````````````
M`+```A``````%0````,``````````````+@``A``````%0````0`````````
M`````,```A``````%0````4``````````````,@``A``````%0````8`````
M`````````-```A``````%0````@``````````````-@``A``````%0````D`
M`````````````.```A``````%0````H``````````````.@``A``````%0``
M``L``````````````/```A``````%0````P``````````````/@``A``````
M%0````X````````````````!`A``````%0````\```````````````@!`A``
M````%0```!```````````````!`!`A``````%0```!$``````````````!@!
M`A``````%0```!(``````````````"`!`A``````%0```!,`````````````
M`"@!`A``````%0```!0``````````````#`!`A``````%0```!4`````````
M`````#@!`A``````%0```!<``````````````$`!`A``````%0```!@`````
M`````````$@!`A``````%0```!H``````````````%`!`A``````%0```!L`
M`````````````%@!`A``````%0```!P``````````````&`!`A``````%0``
M`!T``````````````&@!`A``````%0```!X``````````````'`!`A``````
M%0```!\``````````````'@!`A``````%0```"```````````````(`!`A``
M````%0```"$``````````````(@!`A``````%0```"(``````````````)`!
M`A``````%0```",``````````````)@!`A``````%0```"0`````````````
M`*`!`A``````%0```"4``````````````*@!`A``````%0```"8`````````
M`````+`!`A``````%0```"<``````````````+@!`A``````%0```"@`````
M`````````,`!`A``````%0```"D``````````````,@!`A``````%0```"L`
M`````````````-`!`A``````%0```"T``````````````-@!`A``````%0``
M`"X``````````````.`!`A``````%0```"\``````````````.@!`A``````
M%0```#```````````````/`!`A``````%0```#$``````````````/@!`A``
M````%0```#(````````````````"`A``````%0```#,```````````````@"
M`A``````%0```#0``````````````!`"`A``````%0```#4`````````````
M`!@"`A``````%0```#8``````````````"`"`A``````%0```#<`````````
M`````"@"`A``````%0```#@``````````````#`"`A``````%0```#D`````
M`````````#@"`A``````%0```#H``````````````$`"`A``````%0```#L`
M`````````````$@"`A``````%0```#P``````````````%`"`A``````%0``
M`#T``````````````%@"`A``````%0```#X``````````````&`"`A``````
M%0```#\``````````````&@"`A``````%0```$```````````````'`"`A``
M````%0```$$``````````````'@"`A``````%0```$(``````````````(`"
M`A``````%0```$8``````````````(@"`A``````%0```$<`````````````
M`)`"`A``````%0```$@``````````````)@"`A``````%0```$D`````````
M`````*`"`A``````%0```$H``````````````*@"`A``````%0```$P`````
M`````````+`"`A``````%0```$T``````````````+@"`A``````%0```$X`
M`````````````````````````````````````````````!@`0?B@@8+II@.)
M?2`$@$X#$$`\((!".*8""'P0``'XH?\A^````&`(@`+H``"@+PP`_D'-__]+
M&`!!Z&``(3@0``'HI@,(?"``@$X``````````````````````````!@`0?@X
M@H+II@.)?2`$@$X8`$'XN(&"Z:8#B7T@!(!.&`!!^,B`@NFF`XE](`2`3A@`
M0?B(@H+II@.)?2`$@$X8`$'X>(*"Z:8#B7T@!(!.&`!!^."`@NFF`XE](`2`
M3A@`0?B`@H+II@.)?2`$@$X8`$'XV(&"Z:8#B7T@!(!.&`!!^$B!@NFF`XE]
M(`2`3A@`0?CX@8+II@.)?2`$@$X8`$'X,(&"Z:8#B7T@!(!.&`!!^`B"@NFF
M`XE](`2`3A@`0?@@@8+II@.)?2`$@$X8`$'X6(&"Z:8#B7T@!(!.&`!!^+"!
M@NFF`XE](`2`3A@`0?BH@8+II@.)?2`$@$X8`$'XZ(&"Z:8#B7T@!(!.&`!!
M^"B"@NFF`XE](`2`3A@`0?@P@H+II@.)?2`$@$X8`$'XD(&"Z:8#B7T@!(!.
M&`!!^!B!@NFF`XE](`2`3A@`0?@0@8+II@.)?2`$@$X8`$'XN(""Z:8#B7T@
M!(!.&`!!^%""@NFF`XE](`2`3A@`0?@@@H+II@.)?2`$@$X8`$'XB(&"Z:8#
MB7T@!(!.&`!!^/"`@NFF`XE](`2`3A@`0?A@@H+II@.)?2`$@$X8`$'XH(""
MZ:8#B7T@!(!.&`!!^(B`@NFF`XE](`2`3A@`0?@(@8+II@.)?2`$@$X8`$'X
M6(*"Z:8#B7T@!(!.&`!!^.B`@NFF`XE](`2`3A@`0?CX@(+II@.)?2`$@$X8
M`$'X.(&"Z:8#B7T@!(!.&`!!^'B!@NFF`XE](`2`3A@`0?A0@8+II@.)?2`$
M@$X8`$'X<(&"Z:8#B7T@!(!.&`!!^-"`@NFF`XE](`2`3A@`0?@0@H+II@.)
M?2`$@$X8`$'XP(""Z:8#B7T@!(!.&`!!^$"!@NFF`XE](`2`3A@`0?B`@(+I
MI@.)?2`$@$X8`$'XD(*"Z:8#B7T@!(!.&`!!^,B!@NFF`XE](`2`3A@`0?BP
M@(+II@.)?2`$@$X8`$'XD(""Z:8#B7T@!(!.&`!!^)B"@NFF`XE](`2`3A@`
M0?BH@(+II@.)?2`$@$X8`$'XF(""Z:8#B7T@!(!.&`!!^!B"@NFF`XE](`2`
M3A@`0?B8@8+II@.)?2`$@$X8`$'X8(&"Z:8#B7T@!(!.&`!!^`"!@NFF`XE]
M(`2`3A@`0?C`@8+II@.)?2`$@$X8`$'X<(*"Z:8#B7T@!(!.&`!!^/"!@NFF
M`XE](`2`3A@`0?C0@8+II@.)?2`$@$X8`$'X:(*"Z:8#B7T@!(!.&`!!^$""
M@NFF`XE](`2`3A@`0?AH@8+II@.)?2`$@$X8`$'X*(&"Z:8#B7T@!(!.&`!!
M^("!@NFF`XE](`2`3A@`0?C@@8+II@.)?2`$@$X#$$`\((!".*8""'SP_\'[
M^/_A^Q```?AA_R'X<`"!^&@`H?AP`($X:`"A.'P`89!\`&$X\(\MZ8@`(?D`
M`"`YH?S_2Q@`0>@```!@6(""Z````&!0@&+H>".%?`U>`$@```!@````8&"`
M(ND``,F+``">+^@!GD$```!@.(#BZP``?X#-_?]+&`!!Z'@;:GP``'^`.@8J
MB0(`*6$Z!BJ9L?W_2Q@`0>C^_R(]T&2,\?``:<%\`"&!!0`I.;0'*7U@`"'Y
M``!"8&```<@Z!B.)`0`I8:`%0/$Z!B.9*F"*_0!8C/_D`9U!8``!V```0F!@
M`('H)!^#>,G^_TL8`$'H?`"A@'```>G__T(]^']*Z?[_(CW^_^(\D`0I.8@$
MYS@```!@>!MK?`$`A2\``,CH$`!#^0```&`8`"/Y!``@.<B28O@(`./X``##
M^,"2(I$$`,4X3`"=0/K_)CD%`$`Y(``I>0$`*3FF`RE]%```2````&````!@
M````8```0F`)`.CHM`=)?20?*7D!`$HY^/\I.2``2GDJ2>M\Y/\`0K0'R7P`
M``!@V))BZ```0#DD'REY`P"E./C_*3G^_X(\$,:$.+0'I7QX6V9]``#@."I)
M2WT]^_]+&`!!Z'D;?WRX`()!````8-B28N@```!@L(+".\WZ_TL8`$'H_O]B
M/(0`@3C@`6,X,1\`2```HR^@`)Y!````8-B28NCU^_]+&`!!Z$W\_TL8`$'H
M>/OC?X@`0>GPCXWH>2)*?0``@#C$`,)`H``A.!```>CP_\'K^/_AZZ8#"'P@
M`(!.Y?O_2Q@`0>@```!@``"C+]B28OB<`-Y!+?O_2Q@`0>@```!@.(#BZP``
M?X#)^_]+&`!!Z!T*PYOL_?]+````8-B28NC1_/]+&`!!Z'@;?WPX__]+````
M8-"28N@``*,O)`">02E9`$A0__]+````8&B`@NC^_V(\@`1C."GZ_TL8`$'H
M_O]B/(0`@3A@`6,X31X`2```HR\@$'[X'/_^0>U8`$@4__]+C?K_2Q@`0>@!
M`&`X\?O_2Q@`0>@``````````8`"```#$$`\((!".'@+*7SD!B%X````.('_
M(?BF`PA\```!^!"``NG8^O]+````8```````````0"`,`"P````&`%]S=&%R
M=````&````!@`Q!`/""`0C@```!@````8`>`(CD`@&(X4$@C?0X`J2L@`)U,
M````8!B`(ND``*DO(`">3:8""'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$@$X8
M`$'H(``A.!```>BF`PA\(`"`3@```&````!@``!"8`,00#P@@$(X````8```
M`&``@((X`(!B.%`@@WQT'H1\=`Z$?)4!A'P@`()-````8""`0ND``*HO(`">
M3:8""'QX4TQ]I@-)?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\
M(`"`3@``0F`#$$`\((!".````&"@@B*)``")+R``GDRF`@A\$``!^.'_(?@%
M__]+(``A.`$`(#D```!@$``!Z*""(IFF`PA\(`"`3@```&````!@``!"8`,0
M0#P@@$(X__\B/<A]*3EX2R-]```CZ0``J2\4`)Y`*/__2P```&````!@``!"
M8````&`H@"+I``"I+^3_GD&F`@A\>$LL?:8#*7T0``'XX?\A^!@`0?@A!(!.
M&`!!Z"``(3@0``'HI@,(?-S^_TL```!@````8````&````!@`Q!`/""`0CBF
M`@A\8``#Z7#_P?EH`$/I>/_A^8#_`?J(_R'ZD/]!^IC_8?J@_X'Z(@!,>:C_
MH?JP_\'Z$``!^+C_X?K`_P'[R/\A^^1%&'G0_T'[V/]A^QX"&%?@_X'[Z/^A
M^_#_P?OX_^'[(@`?>='[(?CD1?E[<``CZ3@`8^E``(/H4`##Z%@`X^@B`"!Y
MY$5N>2(`_G@>`LY5\(^MZ)@#H?@``*`XV``A^^1%67E(`*/HY$77>Z``(?OD
M19EY*,#>>R(`>GFH`"'[Y$4Y>>1%3WL>`N]5*,!:>[``(?OD11EX*`#!^R#"
M_GAXT_I]Y$60>+@`(?LHP'EYP`#!^P+"'GD>`A!6(@";>#``(?L"PGEYT`#!
M^^1%<7O8`,'K'@(Q5BC`>WM``"'[(,)Y>7C;.W[D1;)X(@"\>$@`(?LHP)EX
M'@)25N1%DWLHP)Q[.``A^P+"F7@>`G-6>.-\?N1%U'A0`"'[(,*9>!X"E%8B
M`-UXY$7V>%@`(?LHP+EXY$6U>QX"M58HP+U[8``A^P+"N7AXZ[U^'@+65AX"
M]U9H`"'[(,*Y>"C`C'DHP`!X<``A^RC`V7AX`"'[`L+9>(``(?L@PMEXB``A
M^RC`^7B0`"'[`L+Y>)@`(?LHP!EYR``A^QX"V5<HP/Y[(,(?>7CS/G_8`.'[
MH`#AZQX"_U>@`.'[*,!?>>``X?L"PE]YZ`#A^Z@`X>L>`O]7J`#A^R#"7WGP
M`.'[L`#AZQX"_U>P`.'[*,`_>?@`X?L"PC]Y``'A^[@`X>L>`O]7N`#A^R#"
M/WD(`>'[,`#AZWC[SGU``.'K+@3_5S``X?M(`.'K+@3O5S@`X>MX>T]_(D:Z
M>"!&I7AX^Q!^4`#AZRX$_U<X`.'[6`#AZRX$\5=@`.'K>(M[?WC[4GYH`.'K
M+@3_5U``X?MP`.'K+@3S5W@`X>MXFYQ_($83>7@KA7]X^Y1^@`#AZRX$_U=8
M`.'[B`#AZRX$]5>0`.'K>*N]?R)&]7@@1N=X>/O6?I@`X>LN!/]78`#A^R@`
MX>MX^_=^P`#AZ\``P?O8`,'K*`#A^BX$]U?(`.'K+@395^``P>MX^QA_T`#A
MZRX$_U=H`.'[H`#AZWCS_W]P`.'[Z`#AZRX$_U=X`.'[J`#!Z_``X>M``.'Y
M(D;/>"!&QGAX,Z9_+@3_5WACS'^P`,'K@`#A^_@`X>MX^]Y_N`#AZX@`P?L`
M`<'K>`/@?S``X>LN!-Y7>/O.?3@`X>N0`,'["`'!ZWC[$'Y8`.'K+@3>5Y@`
MP?LB1GYY>/N4?B@`X>L@1FMY>'N4?C``P?M0`,'K2`!A^2)&BW@@1H1X>%L0
M?G@C>W]X\U)^8`#!ZWC34GYX\]9^>+O^?V@`X>LB1A=Y<``!Z7@[QW]XJ]9^
M6`'!.WC[&'_``.'K>+L8?Q``X#IXR_E_>`#AZWB;.7]X^Q%](D9(>8``X>L@
M1DIY.``!^8@``>E0`$'YD`!!Z7C[C'UX4Q]]F`!!Z2)&*'D@1BEY>$/D?S``
MX>M```'I>%,`?%``0>EX2QI\2``AZ7C[SGUP`2'[%0`@.R@!`?HP`6'[I@,I
M?WA3BWTX`$'I&`'!^7A+#WTX`4'Z0`&A^$@!@?I0`<'X>%,Q?B`!X?E8`<'Z
M8`'A^&@!`?MX`2'Z@`%A^8@!@?B0`4'[```^Z@@`WND0`-[JT/_^Z'A:"WYX
M(F1_P/\>Z\C_/NMXTEI^`P#W.G@KL'QXHYM^>(IK?7ARA'QXLEI_>,)K?7@Z
M6G]XRH1\P@]J><(/B'C"#TE[I`]K>:0/A'BD#UI[>%M+?7@C!'UXTSI](`!K
M>2``A'@@`%I[4`#W($``?OEX,])\2`">^%``7ONT!_=^(`#G>!@`WCMXBR5^
M>'/4?7BSQGY<_P!"___G.$\`P#@@`.EX`0`I.:8#*7T``$)@(`#)>*`#P3OX
M_^DX_?\).?+_23FT!^=\M`<(?20?YW@D'PAYM`=*??#_*3D4.OY\%$(>?20?
M2GFT!RE]%%)>?7C]I^@D'REY>/WHZ!1*/GUX_0KI>/U)Z7@ZJ7QX0BE]>%(I
M?20?RGC"#RAYI`\I>7A+"7T44EY](``I>0$`QCBT!\9\>/TJ^7C_`$(``,/H
M(``#Z!@!0>D(`*/H$`"#Z!@`8^G"+LAXI"[)>!120'UX2PE]@EI*/7@H?GTX
M*(A\F7E*.2``*7ED\*=X%$HJ?7A#RG\44DE](`$AZ8+POWAX._]_(`!>>2``
M_WMX,(A\%$HK?3@PYW^"6BD]>$/H?"@HVWO"+L=[@O#<>&3PW7B9>2DY%$(I
M?7@[:']XZX=_*`&!ZQ1"*7T@`.=X>/#[?S@X2'T@`#UY%.*$?WA#:G^"6IP_
M*"B[>YEYG#O"+JA[%%)<?8+PW'LH\-Y[>$-H?WCCVG\P`<'K%$)*?7CH^WPX
MT"A]>$-I?X):GC\@`%YYF7F<.\(NR'L4^OQ_*"C<>Q1*/WUX0Y]_@O"\>RCP
MJ'MXXQU].`$!Z13Z*7T@`#]Y>/!;?X):B#\XZ$A]F7F<.WA#:G\4.OQ\PB[H
M>R@H_'L44D=]>$.(?RCPQWN"\-Q[%$)*?7CC_GQ``>'H>/B[?SCP*'UX0VE_
M@EJ'/R``1WF9>9P[PB[H>!32G'\H*/MX%$H\?7A#?'^"\/M[*/#H>WC;'WU(
M`0'I%.(I?2``/'EX.-M_@EI(/SCX2'UX0VI_*"B;>\(NB'N9>5H[>$-H?X+P
M^W@H\.=X%.JZ?WC;^WQ0`>'H%%)=?11"2GUXX/U_.-@H?8):1S\@`$=YF7E:
M.WA#J7\4\MI_PB[H>"@H_7@42CY]>$.^?X+PG7LH\(A[%/(I?7CK''U8`0'I
M(``^>7@X?7^"6D@_..!(?7A#JG\H*-U[PB[(>YEY6CMX0ZA_@O#]>"CPYW@4
M^OI_>.O]?&`!X>@44E]]%$)*?7CPGW\XZ"A]@EI'/R``1WF9>5H[>$/I?Q3:
M>G_"+NAX*"C_>!1*.WUX0_]_@O#;>RCPR'L4^BE]>-L>?6@!`>D@`#MY>#B_
M?X):2#\X\$A]>$/J?R@H?WO"+FA[F7E:.WA#Z'^"\/]X*/#G>!3BFG]X^_]\
M<`'AZ!127'T40DI]>-C<?SCX*'V"6D<_(`!'>9EY6CMX0XE_%.JZ?\(NZ'@H
M*/QX%$H]?7A#G7^"\'Q[*/!H>Q3J*7UXXQM]>`$!Z2``/7EX./Q_@EI(/SC8
M2'UX0XI_*"B\>\(NJ'N9>5H[>$.(?X+P_'@H\.=X%/+:?WCC_'R``>'H%%)>
M?11"2GUXZ'Y_..`H?8):1S\@`$=YF7E:.WA#R7\4^OI_PB[H>"@H_G@42C]]
M>$/??X+POGLH\*A[%/HI?7CS'7V(`0'I(``_>7@XGG^"6D@_..A(?7A#RG\H
M*/Y[PB[H>YEY6CMX0\A_@O#^>"CPYW@4VGI_>//^?)`!X>@44EM]%$)*?7CX
MNG\X\"A]@EIG/R``1WF9>7L[>$-)?Q3BFW_"+NAX*"C[>!1*/'UX0WQ_@O#[
M>RCPZ'L4XBE]>-L??9@!`>D@`#QY>#C:?X):"#V9>6@[./A(?13JNW]X0TI_
M*"B;>\(NB'MX0VA_%%)=?11"2GV@`0'I@O#]>"CPYWAXX/I_>.O]?"``1WF"
M6@@]F7EH.SCH*'T4\MM_>$-)?R@H^WC"+NAX>$-H?Q1*/GT40BE]J`$!Z8+P
MGGLH\)Q[>#BZ?WCSGG\@`#QY@EIH/SCP2'V9>7L[>$-*?Q3Z>W\H*)I[PBZ(
M>Q126WUX0TA_@O#_>!1"2GVP`0'I9/#G>'@[_W\@`%MY(`#Z>WC@V7^"6@@]
M*"AX>YEYZ#@XT"A]%.JG?WA#*7^"\(=[PBYY>V3PB'L42CU]>$/G?'C+"'\4
M0BE]N`$!Z7CZ_WP@`#UY>%+J?R@HO'O"+K][VFX(/2``2GFAZP@Y>/N??Q3R
MR'^"\&A[%%)>?63P>WL4^DI]P`'AZWC;"'UX.AQ](`!>>7A*B7\H*-M[VF[_
M/\(NW'NAZ_\[(``I>1327W^"\+][9/"]>Q1*.GUXZ_]_>.-]?Q3J*7W(`:'K
M>$+\?R``YWAX4HI_(`!*>2``"'G:;GT_(``]>:'K>SO"+KQ[%#I[?R@HNGN"
M\,=[9/#>>WCSYWP44EM]>.->?WCZ^WP4\DI]T`'!ZWA*:7\@`"EY(`#_>]IN
MGC\@`%YYH>N<.\(NVWL40IQ_*"C:>X+PJ'MD\+U[>.L(?11*/'UXVUU_>#H<
M?13J*7W8`:'K>%**?R``.WD@`$IYPBY\>R@H>GO:;KT_(`#G>*'KO3L4^KU_
M@O#?>V3PWGL44EU]>//_?WCC7G\4\DI]X`'!ZWA"_7\@`%QY>$JI?R@HFGO"
M+IU[VF[>/R``*7FAZ]X[(``(>10ZWG^"\&=[%$H^?7CK7G\4\BE]Z`'!ZV3P
M>WMXV^=\(``]>2@HNGO:;GX_>/K^?'A2RG^AZWL[%$)[?\(NOGL@`$IY>/->
M?Q126WV"\(A[%/)*??`!P>MD\)Q[>.,(?2``_WMX.AM](`#G>-INGC]X2FE_
M(`!>>:'KG#L4^IQ_PB[;>R@HVGN"\+][(``I>63PO7MXZ_]_%$H\?7C;77]X
M0OQ_%.HI??@!H>MX4HI_(``[>2``2GG"+GQ[*"AZ>]INO3\@``AYH>N].Q0Z
MO7^"\,=[9/#>>Q1277UX\^=\>.->?Q3R2GT``L'K>/K]?"``7'EX2JE_*"B:
M>\(NG7O:;MX_(``I>:'KWCL@`/][%$+>?X+P:'L42CY]>.M>?Q3R*7T(`L'K
M9/![>WC;"'T@`#UY*"BZ>]IN?C]X.AY]>%+*?Z'K>SL4^GM_PBZ^>R``2GEX
M\UY_%%);?8+PGWL4\DI]$`+!ZV3PG'MXX_]_(`#G>'A"^W\@``AYVFZ>/WA*
M:7\@`%YYH>N<.Q0ZG'_"+MM[*"C:>X+PIWL@`"EY9/"]>WCKYWP42CQ]>-M=
M?WCZ^WP4ZBE]&`*AZWA2:G\@`#QY(`!*><(NFWLH*)I[VFZ]/R``_WNAZ[T[
M%$*]?X+PR'MD\-Y[%%)=?7CS"'UXVUY_%/)*?2`"P>MX.AM](`!=>7A*:7\H
M*+I[PBZ[>]INWC\@`"EYH>O>.R``YW@4^MY_@O"?>Q1*/GUXVUY_%/(I?2@"
MP>MD\)Q[>./_?R``/'EX0OM_*"B:>]INWC]X4FI_H>O>.\(NFWL4.OY\(`!*
M>1121WUXVT=_%#I*?3`"X>B"\+Y[9/"]>R``"'EXZ]Y_(`!=>=IN9S]X^L=_
M>$KI?*'K>SL40GM_*"BZ>\(NIWL@`"EY>#M'?Q1*.WT4.BE].`+AZ(+PB'MD
M\)Q[(`#_>WCC"'UX\AM]VFZ'/WA2:G\@`"=YH>N<.\(N^W@4^IQ_*"CZ>(+P
MOWL@`$IY9/"]>Q127'UXZ_]_>-M=?Q3J2GU``J'K>$+\?R``6WD@`-Y[>$J)
M?R@H>GO:;KT_PBY\>Z'KO3L@`"EY%/*]?X+P_GAD\.=X%$H]?7@[WG]XXT=_
M%#HI?4@"X>AX^MU_(``\>2``"'EX4JI_*"B:>]INYSS"+IU[H>OG."``2GD4
M0N=\@O!H>Q121WUXZT=_%#HJ?U`"X>AD\'M[>-L(?2``/7N"\(I[(`#_>]IN
M9S]D\)Q[>/('?:'K>SMXXTI]%/K[?WA*Z7PH*+M[PBZ\>R``)WEXXWQ_&X\@
M/5@"8>L4.O]\W+PI82``*7D4XH=_(`":>WA#7WT4VFE_@O"G>R``WGMD\+U[
M>.OG?#CX.7\4\MM_.$!??<(N77LH*%M[>/L_?WCK>W]X4_U\(`#_>SCHG']@
M`J'K%/K^?Q3:?W\X4/Y\(`!Y>R``'WD4ZJE_>/.>?V3P2'N"\%Q[>$.(?Q3Z
M_7\H*#Q[PBX]>WCKG']X.QU]..A[?R``WGMH`J'K%/+_?S@X'GT4XI]_>/-^
M?R``FGL4ZJE_@O`[>R``7WED\"I[%/K]?WA3:G_"+EU[*"A;>R``WGMXZWM_
M>$-=?3CHG']P`J'K%/+_?Q3:?W\X0%Y](`!Y>R``_W@4ZJE_>/.>?V3P1WN"
M\%Q[>#N'?Q3Z_7\H*#Q[PBX]>WCKG']X4_U\..A[?R``WGMX`J'K%/+_?SA0
M_GP4XI]_>/-^?R``FGL4ZJE_@O`[>R``'WED\"A[%/K]?WA#:'_"+EU[*"A;
M>R``WGMXZWM_>#L=?3CHG'^``J'K%/+_?Q3:?W\X.!Y](`!Y>R``7WD4ZJE_
M>/.>?V3P2GN"\%Q[>%.*?Q3Z_7\H*#Q[PBX]>WCKG']X0UU]..A[?R``WGN(
M`J'K%/+_?SA`7GT4XI]_>/-^?R``FGL4ZJE_@O`[>R``_WAD\"=[%/K]?W@[
M9W_"+EU[*"A;>R``WGMXZWM_>%/]?#CHG'^0`J'K%/+_?Q3:?W\X4/Y\(`!Y
M>R``'WD4ZJE_>/.>?V3P2'N"\%Q[>$.(?Q3Z_7\H*#Q[PBX]>WCKG']X.QU]
M..A[?R``WGN8`J'K%/+_?S@X'GT4XI]_>/-^?R``FGL4ZJE_@O`[>R``7WED
M\"I[%/K]?WA3:G_"+EU[*"A;>R``WGMXZWM_>$-=?3CHG'^@`J'K%/+_?Q3:
M?W\X0%Y](`!Y>R``_W@4ZJE_>/.>?V3P1WN"\%Q[>#N'?Q3Z_7\H*#Q[PBX]
M>WCKG']X4_U\..A[?R``WGNH`J'K%/+_?SA0_GP4XI]_>/-^?R``FGL4ZJE_
M@O`[>R``'WED\"A[%/K]?WA#:'_"+EU[*"A;>R``WGMXZWM_>#L=?3CHG'^P
M`J'K%/+_?Q3:?W\X.!Y](`!Y>R``7WD4ZJE_>/.>?V3P2GN"\%Q[>%.*?Q3Z
M_7\H*#Q[PBX]>WCKG']X0UU]..A[?R``WGNX`J'K%/+_?SA`7GT4XI]_>/-^
M?R``FGL4ZJE_@O`[>R``_WAD\"=[%/K]?W@[9W_"+EU[*"A;>R``WGMXZWM_
M>%/]?#CHG'_``J'K%/+_?Q3:?W\X4/Y\(`!Y>R``'WD4ZJE_>/.>?V3P2'N"
M\%Q[>$.(?Q3Z_7\H*#Q[PBX]>WCKG']X.QU]..A[?R``WGO(`J'K%/+_?S@X
M'GT4XI]_>/-^?R``FGL4ZJE_@O`[>R``7WED\"I[%/K]?WA3:G_"+EU[*"A;
M>R``WGMXZWM_>$-=?3CHG'_0`J'K%/+_?Q3:?W\X0%Y](`!Y>R``_W@4ZJE_
M>/.>?V3P1WN"\%Q[>#N'?Q3Z_7\H*#Q[PBX]>WCKG']X4_U\..A[?R``WGO8
M`J'K%/+_?SA0_GP4XI]_>/-^?R``FGL4ZJE_@O`[>R``'WED\"A[%/K]?WA#
M:'\@`-Y[*"A;>\(N77L4\O]_>.M]?Q3J?W_@`J'K>#L>?3CPG'\X.!Y](`!Y
M>R``7WD4ZJE_>/.>?V3P2GN"\%Q[>%.*?Q3Z_7\@`-Y[PBX]>R@H/'L4\O]_
M>.N<?WA#77T4XE]_Z`*!ZSCH>W\X0%]](`!=>WC[?W]D\#Y[%.*)?X+P.WL@
M`.=X>/-^?Q0Z_'P@`/][PBZ\>R@HNWMXXWM_%/KG?!3:YW_P`F'K>%/<?SC@
M6G\X4,=_(`#\>W@[1W\4VBE](``(><(NFGLH*)E[%$()?2``YW@4.@A]@O"[
M>WC3)W]D\+U[^`)!ZV+*(#UXZWM_UL$I810ZZ'P@`"EY>/)H?R``_7@4TDE_
M>/H(?8+PF'MD\)][(`!*>7C[''\H*+E[``/AZQ126GT@``AYPBZZ>Q1"2GUX
MTRA_%/KI?Q1""GUXVHI_(``9>2``WGMX.D=]%/+_?R@H.GO"+CY[(`#J>(+P
MN'MD\*=[%%)??7@['7]X\T=_"`-!ZQ0Z2GUXXJ=_(`!8>2``?GL4TDE_>$+H
M?!3R6G\H*!M[PBX'>R``"'ED\#][>#MG?Q`#8>N"\#Y[%$(:?7C[WG\4.@A]
M(``9>7CJWW\@`(=[%-II?R@H/'MX4NI_PBX_>Q0Z>W^"\!I[>/N??Q@#@>MD
M\`=[(`!*>7@[1W\44EM]%/I*?7CR^WP@`%IY(`"_>Q3BB7]X0FA_%/J<?R@H
M6WO"+EU[(``(>7CK?7\40AQ]@O`X>Q3J"'T@`Z'K9/`_>R``&WEX^Q]_(`#>
M>W@Z_'\4ZJE_>%**?Q3RO7_"+GQ[*"AY>X+P6'MD\%Y[*`-!ZR``2GEX\QY_
M%%)=?7CC/7\4ZDI]>/K=?R``7'D4TDE_(`#G>'A"J'\4.EI_*"B9>X+P>'O"
M+IU[9/!G>R``"'DP`V'K>#L'?WCK/7\40AI]>/+Z?!3J"'T4VFE_(``=>2``
M_WMX4DI_%/I[?\(NNGLH*+E[(`!*>8+PF'MD\)][%%);?7C3/']X^Q]_%.)*
M?3@#@>MX.OM_(`!:>2``WGMX0FA_*"A9>Q3BB7_"+EM[%/*<?R``"'F"\+A[
M9/"^>Q1"''UXVSU_%.H(?4`#H>MX\QY_>/K<?R``&WD@`.=X>%**?Q3JJ7_"
M+GQ[%#J]?R@H>7N"\%A[9/!'>T@#0>L@`$IY>#L'?Q1277UXXSU_%.I*?7CR
M_7P@`%QY%-))?R``_WMX0JA_%/I:?R@HF7N"\'A[PBZ=>V3P?WL@``AY4`-A
MZWC['W]XZSU_%$(:?7@Z^G\4Z@A]%-II?R``'7D@`-Y[>%)*?Q3R>W_"+KI[
M*"BY>R``2GF"\)A[9/">>Q126WUXTSQ_>/,>?Q3B2GU8`X'K>/K;?R``6GD@
M`.=X>$)H?R@H67L4XHE_PBY;>Q0ZG'\@``AY@O"X>V3PIWL40AQ]>-L]?Q3J
M"'U@`Z'K>#L'?WCR_'P@`!MY(`#_>WA2BG\4ZJE_PBY\>Q3ZO7\H*'E[(`!*
M>8+P6'L44EU]>.,]?Q3J2GUD\%][:`.AZWC['W\@`%QY>#KZ?R``WGL4ZJE_
M>$)(?Q3RW7_"+II[*"B9>R``"'F"\'A[9/!]>Q1"'GUXTSY_<`-!ZWCK'7\4
M\@A](``>>7CZNW\H*-E[%-))?R``YWAX4FI_PB[;>Q0Z6G^"\)A[9/"'>R``
M2GEXVSQ_>`-AZQ126GUX.P=_%.)*?2``_WL@`%AY>.K\?!3::7]X0HA_%/I[
M?\(N''LH*!][(``(>7CC_W^``X'K@O#:>Q1"&WUD\-Y[>/-:?Q3Z"'T@`!EY
M>#I??Q3BB7\@`+U[%.J<?WA2ZG_"+CY[9/`?>R@H.WN"\!U[>/N]?R``2GEX
M\W]_B`/!ZQ127'T4^DI]>-*_?R``6WD@`.=X%/+)?WA"_W\4.MY_(`#_>\(N
M9WLH*&A[%/K^?W@["'T40A]]@O`X>Y`#X>MD\#Q[(``(>7CC''^"\'Y[>.J'
M?Q3Z*7UX4NI\(`!?>Q3ZZ7_"+@=Y(`!)>2@H&GDH\&I[%$H_?7@[1W\4.BE]
M>/-'?10R*7T4*DA]%`+=?!0B!WT46OQ\(``I>2``2GD@``AY(`#G>"``QG@`
M`"/Y"`!#^1```_D8`./X(`##^)@#X>OPCZWH>2K_?P``H#A<`,)`,`0A.!``
M`>AP_\'I>/_AZ8#_`>J(_R'JD/]!ZIC_8>J@_X'JJ/^AZK#_P>JX_^'JP/\!
MZZ8#"'S(_R'KT/]!Z]C_8>O@_X'KZ/^AZ_#_P>OX_^'K(`"`3GW<_TL8`$'H
M``````````&`$@``````8```0F`#$$`\((!".```(RPX`8)!I@((?-#_0?O8
M_V'[X/^!^^C_H?OP_\'[^/_A^P```&`P@"+I$``!^+'_(?@``&GK``"[+Y``
MGD$``".)``"I+^P`GD$]`(DO``#`.R0`GD%X&WY\`0`^C0``*2\]`(DO"`":
M0?#_GD!0\,-_M`?>?P``^^L``+\O3`">07@CFGQX&WQ\>-M]?P```&```$)@
M>/OC?WCCA']X\\5_Q=K_2Q@`0>@``*,O$`">0*[P/WT]`(DO/`">00D`_>L`
M`+\OT/^>0%``(3@``&`X$``!Z-#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#
M"'P@`(!.4.B[?U``(3AT'KU_`0!^.!0:?WP``+J3$``!Z-#_0>O8_V'KX/^!
MZ^C_H>OP_\'K^/_AZZ8#"'P@`(!.``#`.T#__TL``&`X(`"`3@`````````!
M@`8``````&```$)@`Q!`/""`0CBF`@A\Z/^A^]C_8?MY&WU\X/^!^_#_P?OX
M_^'[$``!^-'^(?CPCRWI^``A^0``(#D0`()!```]B0``B2\\`)Y`^`!!Z?"/
M+>EY2DI]```@.7`!PD`P`2$X$``!Z-C_8>O@_X'KZ/^AZ_#_P>OX_^'KI@,(
M?"``@$X1V?]+&`!!Z'D;?GR\_X)!_O]B/_@`>SMX\\-_]=O_2Q@`0>AY&W]\
MR`""01,`/XDN`(DOW`">07CKHW\3`/\[P=O_2Q@`0>AX&WQ\>/OC?[';_TL8
M`$'H%.)C?`(`8SBT!V-\W=G_2Q@`0>@!`(`X__^@.'C;9G]XZZ=_>/OH?W@;
M?'PMVO]+&`!!Z`$`8#AXXX1_:`"A."G;_TL8`$'H__^#+WCC@W\4`)Y!@``A
M@28$*54`0(DKB`">0>7:_TL8`$'H>..#?]G8_TL8`$'H>//#?SW;_TL8`$'H
M>1M_?$S_@D````!@````8```0F!X\\-_W=O_2Q@`0>AXZZ-_X=O_2Q@`0>C`
M_O]+``!"8!0`/XD``*DO`/^>02X`B2\8_YY`%0`_B0``B2_L_OY!"/__2P``
M`&````!@``!"8$G^_TN`__]+.=G_2Q@`0>@``````````8`%`````$)@`Q!`
M/""`0CBF`@A\Z/^A^_#_P?OX_^'[````8#B`XNL0``'XP?\A^```?X"UV?]+
M&`!!Z.``(^D``'^`"`"IZZ'9_TL8`$'HK0##BP``?X"1V?]+&`!!Z&`&WGL(
M`"/I(``IZ3`\*55X\SY]`@#=LP``?X!MV?]+&`!!Z.``(^D``'^`"`#)ZUG9
M_TL8`$'H_O^"/```H#AX!(0XM=G_2Q@`0>@H`'[X``!_@#79_TL8`$'HX``C
MZ0``?X`(`,GK(=G_2Q@`0>@0""/I``!_@#``/OD-V?]+&`!!Z.``(^D``'^`
M"`#)Z_G8_TL8`$'H``!`.8`!(^D``*DO&`">00``?X#=V/]+&`!!Z(`!(^FH
M`$GI.`!>^0``?X```,`[P=C_2Q@`0>C@`"/I``!_@`@`*>E``,G[J=C_2Q@`
M0>C@`"/I``!_@`@`*>D@`,G[D=C_2Q@`0>C@`"/I``!_@`@`Z>M]V/]+&`!!
MZ$``(3@X`R/I2``_^1```>CH_Z'K\/_!Z_C_X>NF`PA\(`"`3@`````````!
M@`,`````0F`#$$`\((!".*8""'SH_Z'[\/_!^W@;?GSX_^'[_O]B/'@CG7P`
M`6,X_P^@.!```?BQ[R'X*`"!./"/+>DH$"'Y```@.0W7_TL8`$'HM`=C?```
M@R^L`)U`___C.S`0(3FT!_]_%/I)??CO2HD``(HO@`">07@;?WPH`&$X+P"`
M.'C[Y7]=U_]+&`!!Z```HR]P`)Y!````8#B`(ND``&F`H=?_2Q@`0>AX\\1_
M*`"A.'C[YG_=V/]+&`!!Z"@0(>GPCTWI>5(I?0``0#E<`,)`4!`A.!```>CH
M_Z'K\/_!Z_C_X>NF`PA\(`"`3@``0F```+\OA/_^0````&```$)@````8#B`
M(ND``&F`-=?_2Q@`0>AX\\1_>.NE?Z78_TL8`$'HF/__2UG6_TL8`$'H````
M``````&``P````!"8`,00#P@@$(XI@((?/C_X?L```!@.(#BZQ```?C1_R'X
M``!_@-W6_TL8`$'H``!_@-'6_TL8`$'H````8$"`HNC^_X(\_O_"/!`!A#@@
M`,8XX=?_2Q@`0>@``'^`I=;_2Q@`0>C^_\(\_O^"/'@$QCC^_Z(\,`&$.!#T
MI3AX,\=\````.4W5_TL8`$'H,``A.!```>CX_^'KI@,(?"``@$X`````````
M`8`!`````$)@`Q!`/""`0CBF`@A\T/]!^]C_8?LF@)!]X/^!^[C_X?IX&WQ\
MP/\!^\C_(?OH_Z'[\/_!^_C_X?L(`(&1$``!^)'_(?@``"2)/0`I:30`*7U^
MV2E5(``I>11*9']XVV-_L=;_2Q@`0>@``+PO>!MZ?-@"GD$```!@,(`BZP``
M&>L``+@OT`*>00``_(H``#<N8`*203T`ER]8`IY!>..>?P$`/HT``"DO/0")
M+P@`FD'P_YY`4/#<?[0'WG\``/CK``"_+W@"GD%XPQU_``!"8'C[XW]XXX1_
M>//%?\73_TL8`$'H``"C+Q``GD"N\#]]/0")+YP!GD$)`/WK``"_+]#_GD!X
MPPI_``#@.Q0``$@```!@````8````&```$)@"0`JZ0$`_SNT!_]_``"I+_#_
MGD`"`)\XM`>$?"0?A'@```!@L((B@0``B2^L`9Y!>,,#?]W4_TL8`$'H``"C
M+P``>?@,`MY!`0`_.0``0#DD'REY(`#]>RI)0WT``/R*```9ZP``-RZL`9)!
M/0"7+Z0!GD%XXXE_#```2```0F`4`)Y!`0!)C0``*B\]`(HO\/^:0%!(/'T@
M`"EY`@!Z."0?O7L42F-\(`!C>(73_TL8`$'H``"C+RKI>'R4`=Y!```\B0``
M6>D``*DO*NA*?0``*IDT`)Y!/0")+RP`GD%XXXE_$```2````&```$)@&`":
M00$`"8T``*@O/0`(+P$`"IWL_YY`/0`@.?__>SL``"J9````8````&```$)@
M`0`[C0``J2\!`"J=]/^>0```8#AP`"$X$``!Z`@`@8&X_^'JP/\!Z\C_(>O0
M_T'KV/]AZ^#_@>OH_Z'K\/_!Z_C_X>NF`PA\((&0?2``@$X!`-X[4.BX?Q7R
M_W\BZ+U[9/["07C[XW]IU/]+&`!!Z"``27M`2*-_T/Z<0?__>SO___\[````
M8````&```$)@`0`[C0``J2\!`#^=]/^>0'#__TL```!@````8```0F```,`[
MR/W_2P$`(#D```!@>".#?+""(I%)TO]+&`!!Z'D;?GQ<`()!>,,$?R0?Y7NQ
MTO]+&`!!Z```V?MX\\-_./[_2P``(#F$_O]+$`"`.```X#O\_?]+````8#"`
M(NL``!GK```XZ1``@#@``.`[``"I+]S]_D&<_?]+``!"8/__8#C@_O]+````
M``````.`"0``````8````&```$)@`Q!`/""`0CBF`@A\````8#B`(ND0``'X
MX?\A^```:8"ATO]+&`!!Z````&!`@*+H_O^"//[_PCP0`80X(`#&.+'3_TL8
M`$'H(``A.!```>BF`PA\(`"`3@`````````!@````````&````!@``!"8`,0
M0#P@@$(XI@((?/#_P?OX_^'[$``!^''?(?CPCRWI>"`A^0``(#FYT?]+&`!!
MZ/[_PCS^_P(]>!MG?`$`@#AH`&$X`1"@.$@!QCA8`0@Y<='_2Q@`0>@``(,O
MA`"<06@`83AP$($X`!"@./70_TL8`$'HM`=_?```GR]D`)Q!`0!_.+0'8WS)
MT/]+&`!!Z'D;?GQ,`()!<!"!.'C[Y7\!TO]+&`!!Z```(#EX\\-_KOD^?7@@
M0>GPCRWI>4I*?0``(#DD`,)`D"`A.!```>CP_\'K^/_AZZ8#"'P@`(!.``!@
M.-#__TNIT/]+&`!!Z``````````!@`(`````0F`#$$`\((!".`#__TL`````
M``````````````!@``!"8`,00#P@@$(XI@((?,C_(?O@_X'[>".9?":`D'VX
M_^'ZP/\!^W@;?'S0_T'[V/]A^^C_H?OP_\'[^/_A^P@`@9$0``'X0>\A^```
M`&`P@"+I``#)Z_"/+>EH$"'Y```@.0``OB]P`)Y!_O]B/V`!>SMXVWU_`0`]
MC0``J2\,`)Y!/0")+_#_GD```/[K4.B[?[0'O7\``+\O/`">00``0F!X^^-_
M>-MD?WCKI7_5SO]+&`!!Z```HR\0`)Y`KNA??3T`BB^<`)Y!"0#^ZP``OR_0
M_YY`>..#?R\`@#@%SO]+&`!!Z```H#L``*,OE`">0?[_8CQXXX1_>`%C..WY
M_TMXXX-_:!`AZ?"/3>EY4BE]``!`.1P"PD#`$"$X$``!Z`@`@8&X_^'JP/\!
MZ\C_(>O0_T'KV/]AZ^#_@>OH_Z'K\/_!Z_C_X>NF`PA\((&0?2``@$X```!@
M````8```0F!XXX-_+P"`.'G-_TL8`$'H`0"].Q3JOW\``*,O=/^>0'CC@W_^
M_V(_:=#_2Q@`0>B(`7L[```]+GC;9'^T!WI\>,LC?QW0_TL8`$'H>1M_?$#_
M@D'^_P(__O\B/P``X#H!`%H[D`$8.Y@!.3L`@/=B``#`.P```&````!@``!"
M8```/XD``(DO#`">0/[_XC]P`?\['`"207CKHW]X^^1_<=#_2Q@`0>@``*,O
MT`">07C[XW_=S_]+&`!!Z+0'8WP4&C]]__\IB2\`B2\P`)Y`````8````&``
M``!@``!"8/__0SEX^^5_M`=#?>X9Q7___Z6(+P"%+^C_GD$4&EI]_P^*+XS^
MG4%X^^=_`0"`.``0H#AXPP9_>,LH?WCCB7]H`&$X'<[_2Q@`0>@```!@.(#B
MZP``?X"9SO]+&`!!Z&@`@3B8`:,X`0!@.`7/_TL8`$'H``"C+R``GD```'^`
M<<[_2Q@`0>BP`2.!)@0I50"XB7\D`)Y!``!@.'C;9'_ASO]+&`!!Z```HR]X
M&W]\\/Z>0/S]_TMH`&$X`0"`.-',_TL8`$'H``"C+\S_GD#^_V(\:`"!.'@!
M8SC-]_]+:`!A.+W-_TL8`$'HV/W_2T'-_TL8`$'H``````````.`"0``````
M8````&```$)@```CB0``J2\@`)Y->!MJ?!P``$@```!@````8```0F```"J)
M``"I+R``GD$O`(DO`0!*.>S_GD```"J)>%-#?0``J2_H_YY`(`"`3@``````
M`````````````&```$)@`Q!`/""`0CBF`@A\^/_A^WD;?WSP_\'[$``!^-'_
M(?CP`()!``#?BP``OB_D`)Y!$<[_2Q@`0>C__V,X%!J_?$`HOW\P`)Q`KA@_
M?2\`B2\@`9Y`4"@_?:8#*7T0``!(```EB2\`B2\(`9Y`__^E./#_`$)`*+]_
MB`">0?__)3E`2+]_4"@_?:8#*7TP`=U!__^_+Q@`_D`D`0!(``!"8```)8DO
M`(DO#`">0/__I3CP_P!"4"B_?`(`)3D`$*DKD`"=00```&!X^^1_P(+".P$`
MI3AX\\-_`!#`.)7+_TL8`$'H,``A.'CSPW\0``'H\/_!Z_C_X>NF`PA\(`"`
M3B\`GB^D`)Y`````8```0F`"`&`X;<O_2Q@`0>AY&VE\,`""02X`0#EX2R-]
M``!)L3``(3@0``'H\/_!Z_C_X>NF`PA\(`"`3@```&```$)@,``A.```8#@0
M``'H\/_!Z_C_X>NF`PA\(`"`3@``0F#__R4Y0$B_?U`H/WVF`RE]2`#=0?__
MOR\4`/Y`/```2```)8DO`(DOY/Z>0?__I3CP_P!"T/[_2_[_8CR8`6,X@<O_
M2Q@`0>AX__]+`0`@.:8#*7WH_O]+`0`@.:8#*7W,__]+``````````&``@``
M`Q!`/""`0CBF`@A\V/]A^^C_H?O^_V(_)H"0?<#_`?O(_R'[H`%[.]#_0?O@
M_X'[\/_!^_C_X?L(`(&1_O_"/#``QNC^_^(\.`#GZ!```?@Q_R'X_O\"/4``
M".G^_T(]2`!*Z?[_(CU0`"FA````8#"`HNOPCZWHB`"A^```H#A@`,'X:`#A
M^'```?EX`$'Y@``AL0```&````!@``!"8```7>L``+HO;`">07C;?'\!`#R-
M``"I+PP`GD$]`(DO\/^>0```^NM0X)M_M`><?P``OR]``)Y!>-->?P``0F!X
M^^-_>-MD?WCCA7\%R?]+&`!!Z```HR\0`)Y`KN`_?3T`B2_<"9Y!"0#^ZP``
MOR_0_YY`>--<?_[_0C\``+POL`%:.U@*GD%XTUM_`0`[C0``J2\,`)Y!/0")
M+_#_GD```/SK4-AZ?[0'>W\``+\O1`">07CCGG\```!@``!"8'C[XW]XTT1_
M>-ME?X7(_TL8`$'H``"C+Q``GD"NV#]]/0")+ZP)GD$)`/[K``"_+]#_GD``
M`+PO_O]"/[@!6CL\"IY!>--;?P$`.XT``*DO#`">03T`B2_P_YY```#\ZU#8
M>G^T!WM_``"_+T@`GD%XXYY_````8````&```$)@>/OC?WC31']XVV5_!<C_
M2Q@`0>@``*,O$`">0*[8/WT]`(DOC`F>00D`_NL``+\OT/^>0```O"_^_T(_
MR`%:.QP*GD%XTUM_`0`[C0``J2\,`)Y!/0")+_#_GD```/SK4-AZ?[0'>W\`
M`+\O2`">07CCGG\```!@````8```0F!X^^-_>--$?WC;97^%Q_]+&`!!Z```
MHR\0`)Y`KM@_?3T`B2]L"9Y!"0#^ZP``OR_0_YY`>..??P``OR_^_X(_T`&<
M._@)GD%XXYI_`0`ZC0``J2\,`)Y!/0")+_#_GD```-_K4-!<?[0'6G\``+XO
M1`">07C[^W\```!@``!"8'CSPW]XXX1_>--%?P7'_TL8`$'H``"C+Q``GD"N
MT#Y]/0")+TP)GD$)`-OK``"^+]#_GD```+\O_O\B/^`!.3O<"9Y!>,LZ?P$`
M.HT``*DO#`">03T`B2_P_YY```#?ZU#067^T!UI_``"^+T@`GD%X^_M_````
M8````&```$)@>//#?WC+)']XTT5_A<;_2Q@`0>@``*,O$`">0*[0/GT]`(DO
M+`F>00D`V^L``+XOT/^>0```OR_^_R(_8`$Y.[P)GD%XRSI_`0`ZC0``J2\,
M`)Y!/0")+_#_GD```-_K4-!9?[0'6G\``+XO2`">07C[^W\```!@````8```
M0F!X\\-_>,LD?WC317\%QO]+&`!!Z```HR\0`)Y`KM`^?3T`B2\,"9Y!"0#;
MZP``OB_0_YY```"_+_[_(C_P`3D[G`F>07C+.G\!`#J-``"I+PP`GD$]`(DO
M\/^>0```W^M0T%E_M`=:?P``OB](`)Y!>/O[?P```&````!@``!"8'CSPW]X
MRR1_>--%?X7%_TL8`$'H``"C+Q``GD"NT#Y]/0")+^P(GD$)`-OK``"^+]#_
MGD```+\O_O\B/P`".3L,!9Y!>,LZ?P$`.HT``*DO#`">03T`B2_P_YY```#?
MZU#067^T!UI_``"^+T@`GD%X^_M_````8````&```$)@>//#?WC+)']XTT5_
M!<7_2Q@`0>@``*,O$`">0*[0/GT]`(DO7`2>00D`V^L``+XOT/^>0```OR_^
M_R(_$`(Y.^P$GD%XRSI_`0`ZC0``J2\,`)Y!/0")+_#_GD```-_K4-!9?[0'
M6G\``+XO2`">07C[^W\```!@````8```0F!X\\-_>,LD?WC317^%Q/]+&`!!
MZ```HR\0`)Y`KM`^?3T`B2\\!)Y!"0#;ZP``OB_0_YY```"_+_[_(C]X`3D[
MS`2>07C+.G\!`#J-``"I+PP`GD$]`(DO\/^>0```W^M0T%E_M`=:?P``OB](
M`)Y!>/O[?P```&````!@``!"8'CSPW]XRR1_>--%?P7$_TL8`$'H``"C+Q``
MGD"NT#Y]/0")+QP$GD$)`-OK``"^+]#_GD```+\O_O\B/R`".3NL!)Y!>,LZ
M?P$`.HT``*DO#`">03T`B2_P_YY```#?ZU#067^T!UI_``"^+T@`GD%X^_M_
M````8````&```$)@>//#?WC+)']XTT5_A</_2Q@`0>@``*,O$`">0*[0/GT]
M`(DO_`.>00D`V^L``+XOT/^>0/[_(C\P`CD[``"_+S0"GD%XRSI_`0`ZC0``
MJ2\,`)Y!/0")+_#_GD```!_K4-!9?[0'6G\``#@N2`"207C[^W]XPQY_````
M8```0F!X\\-_>,LD?WC317\%P_]+&`!!Z```HR\0`)Y`KM`^?3T`B2\,`IY!
M"0#;ZP``OB_0_YY`_O]B/T`">SMXVVE_`0!)C0``JB\,`)Y!/0"*+_#_GD!0
M2#M]M`<^?4@`DD%X^_I_````8````&```$)@>,,#?WC;9']X\\5_E<+_2Q@`
M0>@``*,O$`">0*[P.'T]`(DO\`:>00D`&NL``+@OT/^>0/[_(C]8`CD[>,LI
M?P$`28T``*HO#`">03T`BB_P_YY````?ZU!(.7UX^_I_M`<[?0``N"]XPQY_
M[`:>07CSPW]XRR1_>-ME?R7"_TL8`$'H``"C+Q``GD"NV#Y]/0")+U0&GD$)
M`-KK``"^+]#_GD!XPQE__O]"/W`"6CMXTTE_`0!)C0``JB\,`)Y!/0"*+_#_
MGD```+DO4$@Z?;0'/7UX^_M_>,L^?X0&GD%X\\-_>--$?WCKI7^UP?]+&`!!
MZ```HR\0`)Y`KN@^?3T`B2]P!9Y!"0#;ZP``OB_0_YY`>,L^?_[_8C^``GL[
M>-MI?P$`28T``*HO#`">03T`BB_P_YY```"^+U!(.WVT!SU]0`">00```&``
M`$)@>//#?WC;9']XZZ5_1<'_2Q@`0>@``*,O$`">0*[H/GT]`(DOR`6>00D`
MW^L``+XOT/^>0/[_@CQQ`&$XJ`*$.`H`H#@-P?]+&`!!Z```HR_L!)Y`_O]B
M/'L`@3CP`6,X6>S_2]@$`$@```!@``!"8/C06G]0V#]]`/"Z?W0>*7VT!RE]
M\/W>020?*7D42E]]"0`*Z0``J"\J21]]%`">00D`*ND``*DO^/\J^?3_GD``
M`/WK2/W_2P```&```$)@^-!:?U#8/WT`\+I_=!XI?;0'*7V@^]Y!)!\I>11*
M7WT)``KI``"H+RI)'WT4`)Y!"0`JZ0``J2_X_RKY]/^>0```_>L``+\O_/J>
M0```X#MD^_]+````8````&```$)@^-!:?U#8/WT`\+I_=!XI?;0'*7W`^]Y!
M)!\I>11*7WT)``KI``"H+RI)'WT4`)Y!"0`JZ0``J2_X_RKY]/^>0```_>L`
M`+\O'/N>0```X#N$^_]+````8````&```$)@^-!:?U#8/WT`\+I_=!XI?;0'
M*7W@^]Y!)!\I>11*7WT)``KI``"H+RI)'WT4`)Y!"0`JZ0``J2_X_RKY]/^>
M0```_>L``+\O//N>0```X#ND^_]+````8````&```$)@^-!:?U#8/WT`\+I_
M=!XI?;0'*7T`_-Y!)!\I>11*7WT)``KI``"H+RI)'WT4`)Y!"0`JZ0``J2_X
M_RKY]/^>0```_>L``+\O7/N>0```X#O$^_]+````8````&```$)@^."<?U#P
M.GT`^+Q_=!XI?;0'*7T@]MY!)!\I>11*6GT)``KI``"H+RI)&GV4]9Y!"0`J
MZ0``J2_X_RKY]/^>0(#U_TL```!@````8```0F#XV'M_4/`\?0#XNW]T'BE]
MM`<I?5#VWD$D'REY%$I<?0D`"ND``*@O*DD<?10`GD$)`"KI``"I+_C_*OGT
M_YY```"=ZP``O"^P]9Y```"`.Q3V_TL```!@````8```0F#XV'M_4/`\?0#X
MNW]T'BE]M`<I?7#VWD$D'REY%$I<?0D`"ND``*@O*DD<?10`GD$)`"KI``"I
M+_C_*OGT_YY```"=ZP``O"_,]9Y```"`.S3V_TL```!@````8```0F#XV'M_
M4/`\?0#XNW]T'BE]M`<I?9#VWD$D'REY%$I<?0D`"ND``*@O*DD<?10`GD$)
M`"KI``"I+_C_*OGT_YY```"=ZP``O"_L]9Y```#@.UCV_TL```!@````8```
M0F#XT%I_4-@_?0#PNG]T'BE]M`<I?;#VWD$D'REY%$I??0D`"ND``*@O*DD?
M?10`GD$)`"KI``"I+_C_*OGT_YY```#]ZP``OR\0]IY```#@.W3V_TL```!@
M````8```0F#XT%I_4-@_?0#PNG]T'BE]M`<I?=#VWD$D'REY%$I??0D`"ND`
M`*@O*DD??10`GD$)`"KI``"I+_C_*OGT_YY```#]ZP``OR\L]IY```#@.Y3V
M_TL```!@````8```0F#XT%I_4-@_?0#PNG]T'BE]M`<I??#VWD$D'REY%$I?
M?0D`"ND``*@O*DD??10`GD$)`"KI``"I+_C_*OGT_YY```#]ZP``OR],]IY`
M``#@.[3V_TL```!@````8```0F#XT%I_4-@_?0#PNG]T'BE]M`<I?1#WWD$D
M'REY%$I??0D`"ND``*@O*DD??10`GD$)`"KI``"I+_C_*OGT_YY```#]ZP``
MOR]L]IY```#@.]3V_TL!`)TX%2*>?)CZPD'^_V(\8`%C.('G_TO^_X(\>..#
M?[@"A#AQY_]+B``AZ?"/3>EY4BE]``!`.;P`PD#0`"$X$``!Z`@`@8'`_P'K
MR/\AZ]#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@@9!](`"`3@$`FS@5
M(IY\M/G"0?[_8CR8`F,X#>?_2P``_>L``+\O?/K>00``/^N8^?]+`0">.!4B
MF'P8^<)!_O]B/``"8SCAYO]+``#]ZP``OR\`^9Y`3/K_2P$`O3L5ZIY\0/K"
M0?[_8CSP`6,XN>;_2SC__TL``"`[3/G_2P``P#NT^?]+*;S_2Q@`0>@`````
M`````X`(`````$)@`Q!`/""`0CC__V(\\']C@/__@R^T!V-\(`">3*8""'S@
M_X'[Z/^A^_#_P?OX_^'[````8#"`(ND0``'XP?\A^```J>L``+TO;`">0?[_
M@C_P`9P[>..>?P$`/HT``"DO/0")+P@`FD'P_YY```#]ZU#PW'^T!]Y_``"_
M+S@`GD%X^^-_>..$?WCSQ7^5NO]+&`!!Z```(RP0`()`KO`_?3T`B2\\`)Y!
M"0#]ZP``OR_0_YY```!@.$``(3C__R(]$``!Z.#_@>OH_Z'K\/_!Z_C_X>OP
M?VF0I@,(?"``@$X!`-X[%/(_?0``J2_,_YY!KO`_?0``J2_`_YY!,``C:=``
M8WS@#V-XL/__2P`````````!@`0``````&```$)@`Q!`/""`0CBF`@A\$``!
M^.'_(?C-N_]+&`!!Z+6Y_TL8`$'H```C+!@`@D$``&/H(``A.!```>BF`PA\
M(`"`3@``8#CL__]+``````````&`````````8````&```$)@`Q!`/""`0CBF
M`@A\_O\B/5@`*>G@_X'[_O^"/&``A.BX_^'ZP/\!^\C_(?O0_T'[V/]A^^C_
MH?MY2SQ]\/_!^_C_X?L0``'X$?\A^/[_HCQH`*7H_O_"/'``QNC^_^(\>`#G
MZ/[_`CV```CI_O]"/8@`2NGPCVWIF`!A^0``8#E@`"'Y:`"!^'``H?AX`,'X
M@`#A^(@``?F0`$'YP`""00```&`P@"+K_O_B/O[_`C]X&WI\8`!A.Y`!]SJ(
M`1@[``"YZP``O2]\`)Y!```\B0``J2]L`9Y!/0")+P``P#LD`)Y!>..>?P$`
M/HT``*DO#`">03T`B2_P_YY`4/#<?[0'WG\``/WK``"_+S@`GD%X^^-_>..$
M?WCSQ7^%N/]+&`!!Z```HR\0`)Y`KO`_?3T`B2]\`)Y!"0#]ZP``OR_0_YY`
M>..#?WC31'^]X_]+"0";ZP``O"]H_YY`F`!!Z?"/;>EY6DI]``!@.=P`PD#P
M`"$X$``!Z+C_X>K`_P'KR/\AZ]#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#
M"'P@`(!.````8````&```$)@`0#>.Q7ROW^,_\)!KO!??0``BB^`_YY!>.NC
M?WC31']QM_]+&`!!Z```HR]T_YY`>--#?RVZ_TL8`$'H>!M_?'CKHW\=NO]+
M&`!!Z!0:?WP"`&,X3;C_2Q@`0>@!`(`X__^@.'B[YGYXTT=_>,,(?WCKJ7]X
M&W]\F;C_2Q@`0>AXXX-_>/OD?]'B_TL4__]+``#`.\#^_TM)N/]+&`!!Z```
M```````!@`D`````0F`#$$`\((!".*8""'RH_Z'ZP/\!^_[_HC[0_T'[X/^!
M^W@;>'SP_\'[^/_A^Z#_@?JP_\'ZN/_A^LC_(?L0``'X__\`/-C_8?L`?@!@
MZ/^A^P```&`P@$+K_O^"/Y``G.O^_\(_F`#>Z_[_XC^@`/_K_O]B/;``:^G^
M_X(\N`"$Z&H!(7S^_Z(\P`"EZ*@`%>C^_\(\R`#&Z/[_XCS0`.?H_O\"/=@`
M".G^_T(]X`!*Z?[_(CWH`"GI``"ZZP$`H3[PCRWKF($U^P``(#MP`('[>`#!
M^X``X?N@``'X``"]+Z@`8?FP`('XN`"A^,``P?C(`.'XB``!^9``0?F8`"'Y
M=`">0?[_@C]@`9P[>..)?P$`28T``*HO#`">03T`BB_P_YY```#]ZU!(/'VT
M!SY]``"_+T``GD$```!@``!"8'C[XW]XXX1_>//%?_6U_TL8`$'H``"C+Q``
MGD"N\#]]/0")+^`&GD$)`/WK``"_+]#_GD"MM_]+&`!!Z)6U_TL8`$'H```C
M+.P&@D$``,/K``"^+^`&GD%X\\-_%;C_2Q@`0>BD#V-X`0!C.$6V_TL8`$'H
M``#^B'@;>7P``*<O.`">0?[_XCYX&W]\R`+W.GC[XW\!`(`X__^@.'B[YGZ!
MMO]+&`!!Z`$`_HP"`/\[``"G+]S_GD"@@6$[``#@.@"@]V(!?YOK``"\+Y0`
MGD$``+KK``"]+WP`GD$``#R)``"I+UP#GD$]`(DO``#`.R0`GD%XXYY_`0`^
MC0``J2\,`)Y!/0")+_#_GD!0\-Q_M`?>?P``_>L``+\O.`">07C[XW]XXX1_
M>//%?]6T_TL8`$'H``"C+Q``GD"N\#]]/0")+TP"GD$)`/WK``"_+]#_GD`)
M`)OK``"\+W3_GD!P`,'K``"^+^`"GD$``#Z)``")+]0"GD$``(`[````8#B`
MHNL!`.`[`*"<8T```$@``$`YM`?I?Z"!2F$D'REY%`I*?11**GW__\D_T'[>
MZP``OB^4`IY!```^B0$`_SL@`/][``")+X`"GD$``'V`X;7_2Q@`0>AX\\1_
MF`&C.`$`8#@-M/]+&`!!Z```HR^@_YY```!]@+FU_TL8`$'HL`$C@28$*54`
M0(DK(`">00``?8"=M?]+&`!!Z+`!(X$F!"E5`.")?VC_GD!X\\-_`@"`.!VT
M_TL8`$'H``"C+U#_GD!X\\-_&;7_2Q@`0>AY&WY\//^"07CSPW_^_X(_$;;_
M2Q@`0>B8`9P[>!M_?'C+(W_]M?]+&`!!Z!3Z8WP$!.,[M`?_?WC[XW\EM/]+
M&`!!Z/[_PCS^_R(]`0"`./__H#C0`L8X>//'?WCCB'_@`BDY>,LJ?W@;?7QE
MM/]+&`!!Z'CKHW_``8`XA;7_2Q@`0>C__X,O>`&>00```&`X@,+K``!^@,FT
M_TL8`$'H>.ND?Y@!HS@!`&`X];+_2Q@`0>AY&W=\D`&"00```&!(@"+I``#8
MZ/[_HCP!`(`X<`.E.'CKIW\``&GHE;7_2Q@`0>@``&`X`0"A/IB!->OPCZWJ
M>:HY?P``H#I("\)````AZ!```>B@_X'JJ/^AZK#_P>JX_^'JP/\!Z\C_(>O0
M_T'KV/]AZ^#_@>OH_Z'K\/_!ZZ8#"'SX_^'K(`"`3@$`WCL5\K]_O/W"0:[P
M/WT``(DOL/V>00```&`X@.+K``!_@/VS_TL8`$'H>.ND?Y@!HS@!`&`X*;+_
M2Q@`0>@``*,O@/V>0```?X#5L_]+&`!!Z+`!(X$F!"E5`$")*R``GD$``'^`
MN;/_2Q@`0>BP`2.!)@0I50"XB7](_9Y`>.NC?P(`@#@YLO]+&`!!Z```HR\P
M_9Y`>.NC?S6S_TL8`$'H>1M^?"C]@D$<_O]+``#`.]#\_TL``,`[#/[_2T&Q
M_TL8`$'H```C@1$`B2^T!RA]>/Z>00```&!(@"+I``#8Z/[_HCP!`(`XZ`*E
M.'CKIW\``&GH.;3_2Q@`0>@``&`XI/[_2P``?H`5L_]+&`!!Z+`!(X$F!"E5
M`$")*US^GD```'Z`^;+_2Q@`0>BT`6.#';/_2Q@`0>@`V(-_//Z>0```?H#9
MLO]+&`!!Z+`!(X'^!2E5P`&)*R#^GD!X^^-_O;'_2Q@`0>@``#KK>!M[?```
MN2]L`)Y!_O_"/O@$UCIXL\E^`0!)C0``JB\,`)Y!/0"*+_#_GD```/GK4$@V
M?;0'/GT``+\O.`">07C[XW]XL\1^>//%?[6P_TL8`$'H``"C+Q``GD"N\#]]
M/0")+[0"GD$)`/GK``"_+]#_GD```#CK>,LC?_6R_TL8`$'HM`=_?`,`GR]$
M`)U`_/]_./[_@CP4&GE\*`.$.%&S_TL8`$'H``"C+R0`GD`$`)\OC`>>0?S_
M/SFT!RE]%$HY??__*8DO`(DO=`>>0?__(CWP?RF!__^)+[0'*7UP`IY!``"I
M+QP`GD!XRR-_``"`.!VQ_TL8`$'H>1MW?-0"@D#^_X(\_O]B/+@"A#CP`6,X
M5=O_2_[_PC_^_T(_>`3>.P``X#L9L?]+&`!!Z/[_PCP!`(`X__^@.$@#QCAX
M&VE\>.NG?WC;8W]XXXA_>//*?U@#6CO)L/]+&`!!Z&```$@```!@````8```
M0F`AK_]+&`!!Z```(X$1`(DO6`">0+VP_TL8`$'H8`#!^P$`_SL!`(`XM`?_
M?___H#AX&VE\>--&?WC;8W]XZZ=_>..(?WC[ZG]IL/]+&`!!Z'C;8W_``8`X
MB;'_2Q@`0>C__X,OG/^>07CKHW\UK_]+&`!!Z/[_8CQXVV1_8`%C.'G:_TMX
MVV-_<?7_2WC;8W\X_/]+`0#>.Q7ROW\H^<)!KO`_?0``B2\<^9Y!>.NC?TGU
M_TMXZZ-_.;#_2Q@`0>@(_/]+@`!A.P```&```$)@"0";ZP``O"_``)Y!``"Z
MZP``O2_L_YY!```\B0``J2^@`)Y!/0")+P``P#LD`)Y!>..)?P$`28T``*HO
M#`">03T`BB_P_YY`4$@\?;0'/GT``/WK``"_+Q0`GD"D__]+"0#]ZP``OR^8
M_YY!>/OC?WCCA']X\\5_2:[_2Q@`0>@``*,OW/^>0*[P/WT]`(DOT/^>0`$`
MWCL5\G]\9/_"0:[P/WT``(DO6/^>076O_TL8`$'H>1M^?$C_@D%<^/]+``#`
M.XS__TO^_\(_#0!@.,`"WCM8^/]+`0`^.15*?WQ4_<)!``#XZSFO_TL8`$'H
M>!MD?'C[XW]1WO]+>1MY?#C]XD`P_?]+````8```0F```%KK``"Z+VP`GD'^
M_P(_\`$8.WC#"7\!`$F-``"J+PP`GD$]`(HO\/^>0```^NM02#A]M`<^?0``
MOR\X`)Y!>/OC?WC#!']X\\5_9:W_2Q@`0>@``*,O$`">0*[P/WT]`(DO(`6>
M00D`^NL``+\OT/^>0/__`CUXN^E^\'_HDA3]_TON_X`X`@"@.%6M_TL8`$'H
M>+OC?I@!@3@&`*`XX:W_2Q@`0>B8`2&)``")+Q``GD"9`2&)0P")+_P$GD$`
M`*`X>+OC?@``@#@(`<$Z$:W_2Q@`0>C-[P`]NIA`/=+#(#U%9Z`\B:L(8?[<
M2F$R$,`\\.$I80``X#@!(Z5@(``(>2``2GEV5,9@(``I>=``H?CX`.'XV``!
M^>``0?G0`"$[Z`#!^/``(?D``>'X2`'AD```H#AXN^-^F`&!.`"`I6`]K?]+
M&`!!Z+0'>GP``)HOK`&=0/@`0>DD'TE[%%(I?2``*7E`2*I_>`.=00`!X>A(
M`4&!0A](>_@`(?D40@=]M0='?0`!`?E0`X)!0`!*(7C37W\`4)I_"`"=0'A3
M7WT4.GE\M`?X?S@`8SB8`8$X>,,%?_FM_TL8`$'H2`$A@13Z*7U``(DO2`$A
MD63_GD!0T%]_F`%!.7C+(W^T!UI_%,(*?U&T_TL_`)HOT`"=0'C37G]XPQ]_
M``!"8```OX(8`)^!'``?@"``GX#`_]X[>,LC?R0`OX`H`'^!+`#?@#``_X!`
M`/\[]/\?@?C_7X'\_S^!"`&ADL3_OX(@`8&1)`$!D"@!@9`L`:&0#`&ADLC_
MOX(P`6&1-`'!D#@!X9`\`0&1$`&ADLS_OX)``4&11`$AD10!H9+0_[^"&`&A
MDM3_OX(<`:&2K;/_2S\`GB^T!]Y_:/^=0<#_6CN^T4I7(`!)>3(P2E4!`"DY
M4-!*?V0V*7FT!UI_%$H8?WC317]XPP1_2`#`.'BSPWZ1K?]+&`!!Z```H#AX
MN^-^2`%!DY@!@3@`@*5@E:O_2Q@`0>BT!WI\``":+US^G4%XN^-^/:O_2Q@`
M0>CX`.'KH('A.&%_Q^NB[NI[`0`J.;0'2'TX`(DO%$('?8#_X#BT!RE]"`#H
MF``"G4&@@0$Y-P"J(!1*:'P``(`X:']C.+0'I7Q-K/]+&`!!Z`)&Q7L"A,9[
M0P'!FT<!X9L"PL=[`D;H>P*$ZGL"PNE[0`&AF$$!P9C0`&$X0@'AF$0!`9E%
M`4&91@$AF:&R_TO0`,'HV`#AZ.```>GH`$'I\``AZ0)&U'@"A-5X4P'!F%<!
MX9@"PLQX`D;V>%L!`9E?`4&9`L+X>`)&&7E0`8&:40&AF@*$0'D"PDMY4@&!
MF50!P9H"1B-Y`H0D>58!`9M8`2&;`L(E>5T!`9A>`6&9`H3W>&`!89AA`8&8
M`H0:>0+"'GEB`:&88P$AF0)&7WE5`>&:_O_B/ED!09N0`4$[6@'!FUP!X9M/
M`<$[:`'A.\@"]SH!`/Z,>/OC?P$`@#C__Z`X>+OF?@(`_SMIJO]+&`!!Z$#0
MOW_<_YY```!@.?[_PCS^_T(]__^@.#@#QCAXZZ=_D`%AF7CCB']H`2$Y>`1*
M.0$`@#AXVV-_*:K_2Q@`0>AXZZ-_#:G_2Q@`0>C^_V(\>-MD?V`!8SA1U/]+
M>-MC?TGO_TMXVV-_$/;_2Y@!`3L,_?]+``$!Z0$`Z#B(_/]+"`#XZP``OR^(
M^)Y!>/OC?R&K_TL8`$'H`P"C*W3XG4#\_V,X_O^"/!0:?WPP`X0X@:O_2Q@`
M0>@``*,O5/B>0'C[^7],^/]+T``A.S\`JB`42GE\``"`.+0'I7PX`&,X4:K_
M2Q@`0>C0`&$XW;#_2P``0#D(`4'Y$`%!^1@!0?D@`4'Y*`%!^3`!0?DX`4'Y
MW/W_2P$`WCL``.`Z%/(_?0``J2_@^IY!KO`_?0``X#H``*DOT/J>03``-VG0
M`/=^X`_W>L#Z_TN:`2&)00")+P#[GD";`2&)0P")+_3ZGD"<`2&)2`")+^CZ
MGD"=`2&)10")+]SZGD!XN^-^`@"@.,;_@#CMI_]+&`!!Z)@!@3AXN^-^*0"@
M.'FH_TL8`$'H_O_"//[_0CUXVV-_`0"`./__H#@X`\8X>.NG?WCCB'^8`2$Y
M>`1*.9FH_TL8`$'H2/C_2UVH_TL8`$'H``````````&`#```````8```0F`#
M$$`\((!".*8""'S8_V'[X/^!^^C_H?NX_^'ZP/\!^\C_(?O0_T'[\/_!^_C_
MX?L```!@.("BZQ```?A1_R'X``!]@+VH_TL8`$'H````8#"`@NL!`"`YJ0`C
MF0``?.L``+LO<`">0?[_0C_0`5H[>-->?P$`/HT``*DO#`">03T`B2_P_YY`
M``#[ZU#PVG^T!]Y_``"_+SP`GD$``$)@>/OC?WC31']X\\5_I:;_2Q@`0>@`
M`*,O$`">0*[P/WT]`(DOS`*>00D`^^L``+\OT/^>0)7<_TL``'V`):C_2Q@`
M0>C^_X(\`0"@.,@#A#@+`,`X[:C_2Q@`0>@``",L#`&"00```&#`DB*!$`!#
MZ0$`B2\H`"KK]`"=0"```#\``,`[`0#@.P`$&&,\``!($`"(Z'B[XWX)J?]+
M&`!!Z```HR^P`)Y`$!`Z@0$`_SL!`-X[M`?>?P#XB7^T!_]_M`<I?9P`G4``
M`'V`E:?_2Q@`0>AXRR1_>//%?P``P#CAJ/]+&`!!Z'D;>WSD`X)!```;Z0``
M`&#(DN+H)!_J>P```&"P@D([#``H@2I0YWXX2`E_``2)*WC_GD$``'V`0:?_
M2Q@`0>@``)OH``"@.`(`P#A=I?]+&`!!Z'@;9'QXN^-^7:C_2Q@`0>@``*,O
M6/^>00```&#`DB*!M`<I??__23D`\(I_.`&>00``?8#QIO]+&`!!Z/[_@CP!
M`*`XT`.$.`,`P#BYI_]+&`!!Z'D;?WP\`()!``!]@,6F_TL8`$'H$``_Z?[_
MHCS8`Z4X``")Z"VH_TL8`$'H$``_Z0``*>D,`"F!XU<H><@#@D```'V`C:;_
M2Q@`0>C^_X(\`0"@..`#A#@#`,`X5:?_2Q@`0>AY&WM\*`&"00``7.L``+HO
M<`">0?[_(C]X`3D[>,L^?P$`/HT``*DO#`">03T`B2_P_YY```#ZZU#PV7^T
M!]Y_``"_+SP`GD$``$)@>/OC?WC+)']X\\5_9:3_2Q@`0>@``*,O$`">0*[P
M/WT]`(DOC`*>00D`^NL``+\OT/^>0```?8#II?]+&`!!Z!``6^D```!@R)(B
MZ0``:N@``(GHE<W_2X0"`$@``$)@`0")+\C^G4````!@`0#@.[""0CL```!@
M````8```0F```'V`G:7_2Q@`0>AXRR1_H:7_2Q@`0>@0$#J!`0!?.;0'7WT`
M4(E_V/^=08#^_TL!`-X[%?)??3S]PD&N\#]],0")+S#]GD`!`"J)``")+RC]
MGD$@_?]+````8```0F```'V`/:7_2Q@`0>@``)SKJ0!CFP``O"]L`)Y!_O]"
M/V`!6CMXTUY_`0`^C0``J2\,`)Y!/0")+_#_GD```/SK4/#:?[0'WG\``+\O
M.`">07C[XW]XTT1_>//%?S6C_TL8`$'H``"C+Q``GD"N\#]]/0")+[P`GD$)
M`/SK``"_+]#_GD```"`Y````8-"2(OD```!@R))BZ,'K_TL```!@``"C+]"2
M8OCL`9Y!$``[Z2```#T`!`AA``!)Z0P`*H$X2`E]``2)*X0!GD`0`&KH````
M8,B2XNMX^^1_):+_2Q@`0>@0`#OI(```/0``_^L`!`AA>!M^?```2>D,`"J!
M.$@)?0`$B2L8`9Y`$`"JZ/[_8CQX^^1_$`1C.'CSQG_1HO]+&`!!Z````&``
M`$)@`0#>.P```&`4\O]_````8```OR^P@L([T)+B^T3_WD%X^^-_P`&`.(FD
M_TL8`$'H$0"#+W@;9GP0`)Y!`0`C.0$`B2LP`=U!L``A.!```>BX_^'JP/\!
MZ\C_(>O0_T'KV/]AZ^#_@>OH_Z'K\/_!Z_C_X>NF`PA\(`"`3@``0F````!@
MP)(B@;0'*7W__TDY`/"*?XC\GD"X_?]+``!"8`$`WCL5\O]_?/W"00``?8!A
MH_]+&`!!Z!``.^EX^^5_``")Z,VD_TL8`$'H``!]@$&C_TL8`$'H``"<ZP``
M(#FI`".9``"\+P3^GD!H_O]+``!]@!VC_TL8`$'H$``[Z0``H#@"`,`X``")
MZ#6A_TL8`$'H>!ME?,C^_TL``'V`\:+_2Q@`0>@0`#OI``"@.`(`P#@``(GH
M":'_2Q@`0>A@_O]+``!]@,FB_TL8`$'H$``_Z0``B>CIH?]+&`!!Z"#\_TO^
M_V(\Z`-C.%6A_TL8`$'H&!`^Z?[_8CQX^^5_.`1C.```B>@YH?]+&`!!Z```
M```````!@`D`````0F`#$$`\((!".*8""'S@_X'[^/_A^W@;?'S0_T'[V/]A
M^^C_H?OP_\'[$``!^+'_(?C)U/]+```CB7@;:GQX&W]\``"I+QP`GD`\``!(
M``!"8```*HEX&W]\``"I+R@`GD$O`(DO`0!*.7C[XW_D_YY````JB7A30WUX
M&W]\``"I+^#_GD#__R(]\'\I@;4'*GW__XDO;`">030`@D$``+PO+`">00``
M/(D``(DO(`">0?[_@CQX^^-_X`*$.*6?_TL8`$'H`!B_?_@`GD%0`"$X$``!
MZ-#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@`(!.````8````&```$)@
M````8#"`(ND``&GK```[+'0`@D'^_T(_\`%:.WC327\!`$F-```J+ST`BB\(
M`)I!\/^>0```V^M02#I]M`<]?0``/BQ``()!````8```0F!X\\-_>--$?WCK
MI7]EG_]+&`!!Z```(RP0`()`KN@^?3T`B2\@`)Y!"0#;ZP``/BS0_X)```!@
M./__(CWP?VF0"/__2P$`O3L4ZCY]``"I+^C_GD&NZ#Y]``"I+]S_GD$P`"-I
MT`!C?.$/8WC,__]+4``A.'CC@W\0``'HT/]!Z]C_8>O@_X'KZ/^AZ_#_P>OX
M_^'KI@,(?-#$_TL``````````8`&``````!@``!"8`,00#P@@$(XI@((?/C_
MX?L```!@.(#BZQ```?C1_R'X``!_@$V@_TL8`$'H__^`.#&A_TL8`$'H``!_
M@#6@_TL8`$'H_O^"/```H#@PPX0X,9[_2Q@`0>@P`"$X$``!Z/C_X>NF`PA\
M(`"`3@`````````!@`$``````&````!@`Q!`/""`0CBF`@A\__\B/>A_*3D`
M`*DO$``!^.'_(?@D`-Y!___"/.A_QNC%G?]+&`!!Z"``(3@0``'HI@,(?"``
M@$X``,`XY/__2P`````````!@````````&````!@`Q!`/""`0CBF`@A\T/]!
M^]C_8?MX&WI\X/^!^^C_H?O__Z(_>".;?/#_P?OX_^'[___"/\!]O3NX?=X[
M>"N\?%#HOG\``.`[$``!^+'_(?CX_]X[I9S_2P```&!U'KU_0`""00```&``
M``!@``!"8`D`/NEXTT-_&`!!^'C;9']XXX5_`0#_.Z8#*7UX2RQ](02`3A@`
M0>A`Z+]_U/^>0%``(3@0``'HT/]!Z]C_8>O@_X'KZ/^AZ_#_P>OX_^'KI@,(
M?"``@$X``````````8`&``````!@````8```0F`@`(!.````````````````
M\($!``````"F`@A\!0"?0J8":'WP_TOHI@,(?%!@BWT46F)]T/\,.```B^F"
M\`!XI@.)?0@`:^D@!(!.````8,C__TO$__]+P/__2[S__TNX__]+M/__2[#_
M_TNL__]+J/__2Z3__TN@__]+G/__2YC__TN4__]+D/__2XS__TN(__]+A/__
M2X#__TM\__]+>/__2W3__TMP__]+;/__2VC__TMD__]+8/__2US__TM8__]+
M5/__2U#__TM,__]+2/__2T3__TM`__]+//__2SC__TLT__]+,/__2RS__TLH
M__]+)/__2R#__TL<__]+&/__2Q3__TL0__]+#/__2PC__TL$__]+`/__2_S^
M_TOX_O]+]/[_2_#^_TOL_O]+Z/[_2^3^_TO@_O]+W/[_2]C^_TO4_O]+T/[_
M2\S^_TO(_O]+Q/[_2\#^_TN\_O]+`Q!`/""`0CBF`@A\$``!^*'_(?A@`"$X
M$``!Z*8#"'P@`(!.``````````````````````````#@'@`0`````*!]`!``
M````@'X`$``````!``(`````````````````<&5R;'AS:2YC`````````%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````#XA``0````
M``B%`!``````$(4`$``````8A0`0`````""%`!``````.(4`$```````````
M`````/"$`!``````D($`$````````````````+B"`!``````T(0`$`````#8
MA``0`````."$`!``````Z(0`$````````````````+B$`!``````P(0`$```
M`````````````````%X`````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``````O<')O8R\E:2\E<P``````97AE``````!005)?5$5-4```````
M````+@````````!005)?4%)/1TY!344`````.@`````````E<R5S)7,``"\`
M````````4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?05)'0P``````````4$%27T%21U9?,````````%!!4E]'3$]"04Q?1$5"
M54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?5$U01$E2````````
M4$%27T-,14%./0```````#$`````````4UE35$5-```E,#)X`````"5S)7,E
M<R5S``````````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H```````!P87)L````
M`"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S```````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*````````05)'5@`````8`````````'!E<FP`````,```
M``````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````
M)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"5S````````+64````````M+0``````
M`%5315(`````55-%4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0
M`````%1-4```````+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,
M24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@`````````4TA,24)?
M4$%42````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E
M($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R
M7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!8
M6%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T
M;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M
M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V
M+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S
M*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%
M3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6
M(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%2
M1T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R
M("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?
M+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["G-E96L@7T9(+"`M."P@,CL*<F5A9"!?1D@L("1B=68L(#@["FQA
M<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PIS965K(%]&2"P@+3$R
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TQ,B`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII
M9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L
M;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@
M)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D[
M"G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO
M<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`]('-O<G0@>PIL96YG=&@H)&(I(#P]/B!L
M96YG=&@H)&$I"GT@9W)E<"!["B$O0E-$4$%.+PI](&=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHO7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@
M)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*)&9I;&5S>R1??2LK(&9O<B!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H
M<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H
M+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N
M="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M
M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B
M)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````%``````````!>E(`
M!'A!`1L,`0``````%````!P```!P6?__``0`````````````%````#0```#X
M6/__$```````````````%````$P```#XO/__2`$```!!"4$,1`9!````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(`C`!``````,",`$`````````````````$``````````0`````````!
M``````````4"`````````0````````!4`@````````P`````````D!H`$```
M```-`````````.!_`!``````&0````````#8_0$0`````!L`````````"```
M```````:`````````.#]`1``````'``````````(`````````/7^_V\`````
M6`(`$``````%`````````"@-`!``````!@`````````X`P`0``````H`````
M````\@0````````+`````````!@`````````%0````````````````````,`
M````````D``"$``````"`````````&`&````````%``````````'````````
M`!<`````````"!0`$`````````!P`````+!^`!```````P``<```````````
M``````<`````````,!,`$``````(`````````-@`````````"0`````````8
M`````````/[__V\`````\!(`$`````#___]O``````(`````````\/__;P``
M```:$@`0````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#_____`````$B%`!``
M````((`"$````````````````!"``!``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=#0SH@*%5B=6YT=2`T+CDN,BTQ
M,'5B=6YT=3<I(#0N.2XR`$=#0SH@*%5B=6YT=2`T+C@N-"TQ=6)U;G1U-"D@
M-"XX+C0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9&%T80`N9V]T`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M``````````````````````````````````L````!`````@```````````@`0
M```````"````````$0````````````````````$````````````````````3
M````!P````(`````````%`(`$``````4`@```````"``````````````````
M```$````````````````````(0````<````"`````````#0"`!``````-`(`
M```````D````````````````````!````````````````````#0```#V__]O
M`@````````!8`@`0`````%@"````````X``````````%``````````@`````
M```````````````^````"P````(`````````.`,`$``````X`P```````/`)
M````````!@````$````(`````````!@`````````1@````,````"````````
M`"@-`!``````*`T```````#R!````````````````````0``````````````
M`````$X```#___]O`@`````````:$@`0`````!H2````````U``````````%
M``````````(``````````@````````!;````_O__;P(`````````\!(`$```
M``#P$@```````$``````````!@````(````(````````````````````:@``
M``0````"`````````#`3`!``````,!,```````#8``````````4`````````
M"``````````8`````````'0````$````0@`````````(%``0``````@4````
M````8`8````````%````%@````@`````````&`````````!^`````0````8`
M````````@!H`$`````"`&@```````$P````````````````````@````````
M````````````A`````$````&`````````.`:`!``````X!H`````````90``
M````````````````(````````````````````(H````!````!@````````#@
M?P`0`````.!_````````)`````````````````````0`````````````````
M``"0`````0````(`````````$(``$``````0@````````$!!````````````
M```````0````````````````````F`````$````"`````````%#!`!``````
M4,$```````!D````````````````````!````````````````````*(````.
M`````P````````#8_0$0`````-C]````````"`````````````````````@`
M``````````````````"N````#P````,`````````X/T!$`````#@_0``````
M``@````````````````````(````````````````````N@````$````#````
M`````.C]`1``````Z/T````````(````````````````````"```````````
M`````````+\````&`````P````````#P_0$0`````/#]````````$`(`````
M```&``````````@`````````$`````````#(`````0````,````````````"
M$`````````$``````"`````````````````````(````````````````````
MS@````$````#`````````"```A``````(``!``````!P````````````````
M````"``````````(`````````'D````(`````P````````"0``(0`````)``
M`0``````,`(```````````````````@`````````"`````````#3````"```
M``,`````````P`("$`````"0``$``````$`0```````````````````0````
M````````````````V`````$````P````````````````````D``!``````!'
M`````````````````````0`````````!``````````$````#````````````
M`````````````-<``0``````X0````````````````````$`````````````
%````````
